mpsolve: Multiprecision polynomial solver
=========================================

Description
-----------

MPSolve stands for Multiprecision Polynomial SOLVEr. It is a software that aims to provide an easy to use (hopefully) universal blackbox for solving polynomials and secular equations.


License
-------

GPL v3+


Upstream Contact
----------------

https://numpi.dm.unipi.it/scientific-computing-libraries/mpsolve/

https://github.com/robol/MPSolve
